<!--
SPDX-FileCopyrightText: 2024 PATHFINDER

SPDX-License-Identifier: Unlicense
-->

# Google Tasks to iCal

Version: 1.1.0

A simple CLI tool that converts Google Tasks JSON into iCal VTODO.

## Building

The easiest way to run the source code locally is using
[Poetry](https://python-poetry.org/):

```
poetry install
poetry run google-tasks-to-ical
```

## Repo Map

- `/`: Poetry and README files.
- `/LICENSES/`: Contains the Unlicense file.
- `/google_tasks_to_ical/`: Main source code.
- `/tests/`: Test source code, currently unused.

## Credits

- By [PATHFINDER](https://pathfinderdreams.com/)

## License

This software is dedicated to the public domain. For jurisdictions that do not
recognise such declarations, this software is also licensed under the
[Unlicense](https://choosealicense.com/licenses/unlicense/). See LICENSES for
details.

## See Also

- [Website](https://pathfinderdreams.com/projects/google-tasks-to-ical)
- [Forge](https://forge.pathfinderdreams.com/pathfinder/google-tasks-to-ical)
